# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_price_warehouse.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\'v1/rules/delivery_price_warehouse.proto\x12\x32pro.omni.oms.api.v1.rules.delivery_price_warehouse\x1a\x11\x63ommon/base.proto"\xbb\x01\n\x16\x44\x65liveryPriceWarehouse\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x19\n\x11\x64\x65livery_price_id\x18\x02 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xa3\x01\n#DeliveryPriceWarehouseCreateRequest\x12\x19\n\x11\x64\x65livery_price_id\x18\x01 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x02 \x01(\x05\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdf\x01\n$DeliveryPriceWarehouseCreateResponse\x12l\n\x18\x64\x65livery_price_warehouse\x18\x01 \x01(\x0b\x32J.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xff\x02\n!DeliveryPriceWarehouseReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x98\x02\n"DeliveryPriceWarehouseReadResponse\x12l\n\x18\x64\x65livery_price_warehouse\x18\x01 \x03(\x0b\x32J.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouse\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xcb\x01\n#DeliveryPriceWarehouseUpdateRequest\x12l\n\x18\x64\x65livery_price_warehouse\x18\x01 \x01(\x0b\x32J.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouse\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdf\x01\n$DeliveryPriceWarehouseUpdateResponse\x12l\n\x18\x64\x65livery_price_warehouse\x18\x01 \x01(\x0b\x32J.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"i\n#DeliveryPriceWarehouseDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"q\n$DeliveryPriceWarehouseDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf1\x06\n\x1d\x44\x65liveryPriceWarehouseService\x12\xd3\x01\n\x1c\x44\x65liveryPriceWarehouseCreate\x12W.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseCreateRequest\x1aX.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseCreateResponse"\x00\x12\xcd\x01\n\x1a\x44\x65liveryPriceWarehouseRead\x12U.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseReadRequest\x1aV.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseReadResponse"\x00\x12\xd3\x01\n\x1c\x44\x65liveryPriceWarehouseUpdate\x12W.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseUpdateRequest\x1aX.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseUpdateResponse"\x00\x12\xd3\x01\n\x1c\x44\x65liveryPriceWarehouseDelete\x12W.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseDeleteRequest\x1aX.pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_price_warehouse_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYPRICEWAREHOUSE"]._serialized_start = 115
    _globals["_DELIVERYPRICEWAREHOUSE"]._serialized_end = 302
    _globals["_DELIVERYPRICEWAREHOUSECREATEREQUEST"]._serialized_start = 305
    _globals["_DELIVERYPRICEWAREHOUSECREATEREQUEST"]._serialized_end = 468
    _globals["_DELIVERYPRICEWAREHOUSECREATERESPONSE"]._serialized_start = 471
    _globals["_DELIVERYPRICEWAREHOUSECREATERESPONSE"]._serialized_end = 694
    _globals["_DELIVERYPRICEWAREHOUSEREADREQUEST"]._serialized_start = 697
    _globals["_DELIVERYPRICEWAREHOUSEREADREQUEST"]._serialized_end = 1080
    _globals["_DELIVERYPRICEWAREHOUSEREADRESPONSE"]._serialized_start = 1083
    _globals["_DELIVERYPRICEWAREHOUSEREADRESPONSE"]._serialized_end = 1363
    _globals["_DELIVERYPRICEWAREHOUSEUPDATEREQUEST"]._serialized_start = 1366
    _globals["_DELIVERYPRICEWAREHOUSEUPDATEREQUEST"]._serialized_end = 1569
    _globals["_DELIVERYPRICEWAREHOUSEUPDATERESPONSE"]._serialized_start = 1572
    _globals["_DELIVERYPRICEWAREHOUSEUPDATERESPONSE"]._serialized_end = 1795
    _globals["_DELIVERYPRICEWAREHOUSEDELETEREQUEST"]._serialized_start = 1797
    _globals["_DELIVERYPRICEWAREHOUSEDELETEREQUEST"]._serialized_end = 1902
    _globals["_DELIVERYPRICEWAREHOUSEDELETERESPONSE"]._serialized_start = 1904
    _globals["_DELIVERYPRICEWAREHOUSEDELETERESPONSE"]._serialized_end = 2017
    _globals["_DELIVERYPRICEWAREHOUSESERVICE"]._serialized_start = 2020
    _globals["_DELIVERYPRICEWAREHOUSESERVICE"]._serialized_end = 2901
# @@protoc_insertion_point(module_scope)
