# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/compute.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/rules/compute.proto\x12!pro.omni.oms.api.v1.rules.compute\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xfc\x01\n\x07\x43ompute\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x61ta_request\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61ta_process\x18\x03 \x01(\t\x12\x1e\n\x16\x64\x61ta_response_internal\x18\x04 \x01(\t\x12\x1e\n\x16\x64\x61ta_response_external\x18\x05 \x01(\t\x12\x0c\n\x04time\x18\x06 \x01(\x02\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc8\x01\n\x14\x43omputeCreateRequest\x12\x14\n\x0c\x64\x61ta_request\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x61ta_process\x18\x02 \x01(\t\x12\x1e\n\x16\x64\x61ta_response_internal\x18\x03 \x01(\t\x12\x1e\n\x16\x64\x61ta_response_external\x18\x04 \x01(\t\x12\x0c\n\x04time\x18\x05 \x01(\x02\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43omputeCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07\x63ompute\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.compute.Compute"\xf0\x02\n\x12\x43omputeReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd8\x01\n\x13\x43omputeReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12;\n\x07\x63ompute\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.rules.compute.Compute"\x8b\x01\n\x14\x43omputeUpdateRequest\x12;\n\x07\x63ompute\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.compute.Compute\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43omputeUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07\x63ompute\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.compute.Compute"Z\n\x14\x43omputeDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43omputeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07\x63ompute\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.compute.Compute2\xa5\x04\n\x0e\x43omputeService\x12\x84\x01\n\rComputeCreate\x12\x37.pro.omni.oms.api.v1.rules.compute.ComputeCreateRequest\x1a\x38.pro.omni.oms.api.v1.rules.compute.ComputeCreateResponse"\x00\x12~\n\x0b\x43omputeRead\x12\x35.pro.omni.oms.api.v1.rules.compute.ComputeReadRequest\x1a\x36.pro.omni.oms.api.v1.rules.compute.ComputeReadResponse"\x00\x12\x84\x01\n\rComputeUpdate\x12\x37.pro.omni.oms.api.v1.rules.compute.ComputeUpdateRequest\x1a\x38.pro.omni.oms.api.v1.rules.compute.ComputeUpdateResponse"\x00\x12\x84\x01\n\rComputeDelete\x12\x37.pro.omni.oms.api.v1.rules.compute.ComputeDeleteRequest\x1a\x38.pro.omni.oms.api.v1.rules.compute.ComputeDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.compute_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_COMPUTE"]._serialized_start = 113
    _globals["_COMPUTE"]._serialized_end = 365
    _globals["_COMPUTECREATEREQUEST"]._serialized_start = 368
    _globals["_COMPUTECREATEREQUEST"]._serialized_end = 568
    _globals["_COMPUTECREATERESPONSE"]._serialized_start = 571
    _globals["_COMPUTECREATERESPONSE"]._serialized_end = 730
    _globals["_COMPUTEREADREQUEST"]._serialized_start = 733
    _globals["_COMPUTEREADREQUEST"]._serialized_end = 1101
    _globals["_COMPUTEREADRESPONSE"]._serialized_start = 1104
    _globals["_COMPUTEREADRESPONSE"]._serialized_end = 1320
    _globals["_COMPUTEUPDATEREQUEST"]._serialized_start = 1323
    _globals["_COMPUTEUPDATEREQUEST"]._serialized_end = 1462
    _globals["_COMPUTEUPDATERESPONSE"]._serialized_start = 1465
    _globals["_COMPUTEUPDATERESPONSE"]._serialized_end = 1624
    _globals["_COMPUTEDELETEREQUEST"]._serialized_start = 1626
    _globals["_COMPUTEDELETEREQUEST"]._serialized_end = 1716
    _globals["_COMPUTEDELETERESPONSE"]._serialized_start = 1719
    _globals["_COMPUTEDELETERESPONSE"]._serialized_end = 1878
    _globals["_COMPUTESERVICE"]._serialized_start = 1881
    _globals["_COMPUTESERVICE"]._serialized_end = 2430
# @@protoc_insertion_point(module_scope)
