# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/import_export.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.utilities import model_pb2 as v1_dot_utilities_dot_model__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n v1/utilities/import_export.proto\x12+pro.omni.oms.api.v1.utilities.import_export\x1a\x11\x63ommon/base.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x18v1/utilities/model.proto"\xc1\x03\n\x0cImportExport\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05micro\x18\x02 \x01(\t\x12\x16\n\x0etype_operation\x18\x03 \x01(\t\x12\x39\n\x05model\x18\x04 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Model\x12\x11\n\tname_file\x18\x05 \x01(\t\x12\x11\n\ttype_file\x18\x06 \x01(\t\x12-\n\tdate_load\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x64\x61te_process\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06status\x18\t \x01(\t\x12\x0f\n\x07message\x18\n \x01(\t\x12.\n\nskip_error\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\r \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xe4\x02\n\x19ImportExportCreateRequest\x12\r\n\x05micro\x18\x01 \x01(\t\x12\x16\n\x0etype_operation\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x11\n\tname_file\x18\x04 \x01(\t\x12\x11\n\ttype_file\x18\x05 \x01(\t\x12-\n\tdate_load\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x64\x61te_process\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x0f\n\x07message\x18\t \x01(\t\x12.\n\nskip_error\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x0b \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1aImportExportCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"\xf5\x02\n\x17ImportExportReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf2\x01\n\x18ImportExportReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12P\n\rimport_export\x18\x03 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"\xa5\x01\n\x19ImportExportUpdateRequest\x12P\n\rimport_export\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1aImportExportUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"_\n\x19ImportExportDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1aImportExportDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport2\xb7\x05\n\x13ImportExportService\x12\xa7\x01\n\x12ImportExportCreate\x12\x46.pro.omni.oms.api.v1.utilities.import_export.ImportExportCreateRequest\x1aG.pro.omni.oms.api.v1.utilities.import_export.ImportExportCreateResponse"\x00\x12\xa1\x01\n\x10ImportExportRead\x12\x44.pro.omni.oms.api.v1.utilities.import_export.ImportExportReadRequest\x1a\x45.pro.omni.oms.api.v1.utilities.import_export.ImportExportReadResponse"\x00\x12\xa7\x01\n\x12ImportExportUpdate\x12\x46.pro.omni.oms.api.v1.utilities.import_export.ImportExportUpdateRequest\x1aG.pro.omni.oms.api.v1.utilities.import_export.ImportExportUpdateResponse"\x00\x12\xa7\x01\n\x12ImportExportDelete\x12\x46.pro.omni.oms.api.v1.utilities.import_export.ImportExportDeleteRequest\x1aG.pro.omni.oms.api.v1.utilities.import_export.ImportExportDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.import_export_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_IMPORTEXPORT"]._serialized_start = 192
    _globals["_IMPORTEXPORT"]._serialized_end = 641
    _globals["_IMPORTEXPORTCREATEREQUEST"]._serialized_start = 644
    _globals["_IMPORTEXPORTCREATEREQUEST"]._serialized_end = 1000
    _globals["_IMPORTEXPORTCREATERESPONSE"]._serialized_start = 1003
    _globals["_IMPORTEXPORTCREATERESPONSE"]._serialized_end = 1188
    _globals["_IMPORTEXPORTREADREQUEST"]._serialized_start = 1191
    _globals["_IMPORTEXPORTREADREQUEST"]._serialized_end = 1564
    _globals["_IMPORTEXPORTREADRESPONSE"]._serialized_start = 1567
    _globals["_IMPORTEXPORTREADRESPONSE"]._serialized_end = 1809
    _globals["_IMPORTEXPORTUPDATEREQUEST"]._serialized_start = 1812
    _globals["_IMPORTEXPORTUPDATEREQUEST"]._serialized_end = 1977
    _globals["_IMPORTEXPORTUPDATERESPONSE"]._serialized_start = 1980
    _globals["_IMPORTEXPORTUPDATERESPONSE"]._serialized_end = 2165
    _globals["_IMPORTEXPORTDELETEREQUEST"]._serialized_start = 2167
    _globals["_IMPORTEXPORTDELETEREQUEST"]._serialized_end = 2262
    _globals["_IMPORTEXPORTDELETERESPONSE"]._serialized_start = 2265
    _globals["_IMPORTEXPORTDELETERESPONSE"]._serialized_end = 2450
    _globals["_IMPORTEXPORTSERVICE"]._serialized_start = 2453
    _globals["_IMPORTEXPORTSERVICE"]._serialized_end = 3148
# @@protoc_insertion_point(module_scope)
