# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import location_pb2 as v1_dot_rules_dot_location__pb2


class LocationServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.LocationCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationCreate",
            request_serializer=v1_dot_rules_dot_location__pb2.LocationCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_location__pb2.LocationCreateResponse.FromString,
        )
        self.LocationRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationRead",
            request_serializer=v1_dot_rules_dot_location__pb2.LocationReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_location__pb2.LocationReadResponse.FromString,
        )
        self.LocationUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationUpdate",
            request_serializer=v1_dot_rules_dot_location__pb2.LocationUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_location__pb2.LocationUpdateResponse.FromString,
        )
        self.LocationDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationDelete",
            request_serializer=v1_dot_rules_dot_location__pb2.LocationDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_location__pb2.LocationDeleteResponse.FromString,
        )


class LocationServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def LocationCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_LocationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "LocationCreate": grpc.unary_unary_rpc_method_handler(
            servicer.LocationCreate,
            request_deserializer=v1_dot_rules_dot_location__pb2.LocationCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_location__pb2.LocationCreateResponse.SerializeToString,
        ),
        "LocationRead": grpc.unary_unary_rpc_method_handler(
            servicer.LocationRead,
            request_deserializer=v1_dot_rules_dot_location__pb2.LocationReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_location__pb2.LocationReadResponse.SerializeToString,
        ),
        "LocationUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.LocationUpdate,
            request_deserializer=v1_dot_rules_dot_location__pb2.LocationUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_location__pb2.LocationUpdateResponse.SerializeToString,
        ),
        "LocationDelete": grpc.unary_unary_rpc_method_handler(
            servicer.LocationDelete,
            request_deserializer=v1_dot_rules_dot_location__pb2.LocationDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_location__pb2.LocationDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.location.LocationService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class LocationService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def LocationCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationCreate",
            v1_dot_rules_dot_location__pb2.LocationCreateRequest.SerializeToString,
            v1_dot_rules_dot_location__pb2.LocationCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationRead",
            v1_dot_rules_dot_location__pb2.LocationReadRequest.SerializeToString,
            v1_dot_rules_dot_location__pb2.LocationReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationUpdate",
            v1_dot_rules_dot_location__pb2.LocationUpdateRequest.SerializeToString,
            v1_dot_rules_dot_location__pb2.LocationUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationDelete",
            v1_dot_rules_dot_location__pb2.LocationDeleteRequest.SerializeToString,
            v1_dot_rules_dot_location__pb2.LocationDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
