# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import import_export_pb2 as v1_dot_utilities_dot_import__export__pb2


class ImportExportServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ImportExportCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportCreate",
            request_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportCreateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportCreateResponse.FromString,
        )
        self.ImportExportRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportRead",
            request_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportReadResponse.FromString,
        )
        self.ImportExportUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportUpdate",
            request_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportUpdateResponse.FromString,
        )
        self.ImportExportDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportDelete",
            request_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportDeleteResponse.FromString,
        )


class ImportExportServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ImportExportCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ImportExportRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ImportExportUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ImportExportDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ImportExportServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ImportExportCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ImportExportCreate,
            request_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportCreateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportCreateResponse.SerializeToString,
        ),
        "ImportExportRead": grpc.unary_unary_rpc_method_handler(
            servicer.ImportExportRead,
            request_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportReadResponse.SerializeToString,
        ),
        "ImportExportUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ImportExportUpdate,
            request_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportUpdateResponse.SerializeToString,
        ),
        "ImportExportDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ImportExportDelete,
            request_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.import_export.ImportExportService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ImportExportService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ImportExportCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportCreate",
            v1_dot_utilities_dot_import__export__pb2.ImportExportCreateRequest.SerializeToString,
            v1_dot_utilities_dot_import__export__pb2.ImportExportCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ImportExportRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportRead",
            v1_dot_utilities_dot_import__export__pb2.ImportExportReadRequest.SerializeToString,
            v1_dot_utilities_dot_import__export__pb2.ImportExportReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ImportExportUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportUpdate",
            v1_dot_utilities_dot_import__export__pb2.ImportExportUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_import__export__pb2.ImportExportUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ImportExportDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportDelete",
            v1_dot_utilities_dot_import__export__pb2.ImportExportDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_import__export__pb2.ImportExportDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
