# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/sequence.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bv1/utilities/sequence.proto\x12&pro.omni.oms.api.v1.utilities.sequence\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xb3\x02\n\x08Sequence\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x16\n\x0eimplementation\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x05 \x01(\t\x12\x0e\n\x06suffix\x18\x06 \x01(\t\x12\x0f\n\x07padding\x18\x07 \x01(\x02\x12\x18\n\x10number_increment\x18\x08 \x01(\x05\x12\x1a\n\x12number_next_actual\x18\t \x01(\x05\x12*\n\x06\x61\x63tive\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x0b \x01(\t\x12?\n\x0cobject_audit\x18\x0c \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xff\x01\n\x15SequenceCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x16\n\x0eimplementation\x18\x03 \x01(\t\x12\x0e\n\x06prefix\x18\x04 \x01(\t\x12\x0e\n\x06suffix\x18\x05 \x01(\t\x12\x0f\n\x07padding\x18\x06 \x01(\x02\x12\x18\n\x10number_increment\x18\x07 \x01(\x05\x12\x1a\n\x12number_next_actual\x18\x08 \x01(\x05\x12\x13\n\x0b\x65xternal_id\x18\t \x01(\t\x12\x36\n\x07\x63ontext\x18\n \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x16SequenceCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x42\n\x08sequence\x18\x02 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.sequence.Sequence"\xf1\x02\n\x13SequenceReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe1\x01\n\x14SequenceReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x43\n\tsequences\x18\x03 \x03(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.sequence.Sequence"\x93\x01\n\x15SequenceUpdateRequest\x12\x42\n\x08sequence\x18\x01 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.sequence.Sequence\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x16SequenceUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x42\n\x08sequence\x18\x02 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.sequence.Sequence"[\n\x15SequenceDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16SequenceDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"U\n\x0fNextByIdRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"Y\n\x11NextByCodeRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x1c\n\x0cNextResponse\x12\x0c\n\x04next\x18\x01 \x01(\t2\xd9\x06\n\x0fSequenceService\x12\x91\x01\n\x0eSequenceCreate\x12=.pro.omni.oms.api.v1.utilities.sequence.SequenceCreateRequest\x1a>.pro.omni.oms.api.v1.utilities.sequence.SequenceCreateResponse"\x00\x12\x8b\x01\n\x0cSequenceRead\x12;.pro.omni.oms.api.v1.utilities.sequence.SequenceReadRequest\x1a<.pro.omni.oms.api.v1.utilities.sequence.SequenceReadResponse"\x00\x12\x91\x01\n\x0eSequenceUpdate\x12=.pro.omni.oms.api.v1.utilities.sequence.SequenceUpdateRequest\x1a>.pro.omni.oms.api.v1.utilities.sequence.SequenceUpdateResponse"\x00\x12\x91\x01\n\x0eSequenceDelete\x12=.pro.omni.oms.api.v1.utilities.sequence.SequenceDeleteRequest\x1a>.pro.omni.oms.api.v1.utilities.sequence.SequenceDeleteResponse"\x00\x12{\n\x08NextById\x12\x37.pro.omni.oms.api.v1.utilities.sequence.NextByIdRequest\x1a\x34.pro.omni.oms.api.v1.utilities.sequence.NextResponse"\x00\x12\x7f\n\nNextByCode\x12\x39.pro.omni.oms.api.v1.utilities.sequence.NextByCodeRequest\x1a\x34.pro.omni.oms.api.v1.utilities.sequence.NextResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.sequence_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_SEQUENCE"]._serialized_start = 123
    _globals["_SEQUENCE"]._serialized_end = 430
    _globals["_SEQUENCECREATEREQUEST"]._serialized_start = 433
    _globals["_SEQUENCECREATEREQUEST"]._serialized_end = 688
    _globals["_SEQUENCECREATERESPONSE"]._serialized_start = 691
    _globals["_SEQUENCECREATERESPONSE"]._serialized_end = 858
    _globals["_SEQUENCEREADREQUEST"]._serialized_start = 861
    _globals["_SEQUENCEREADREQUEST"]._serialized_end = 1230
    _globals["_SEQUENCEREADRESPONSE"]._serialized_start = 1233
    _globals["_SEQUENCEREADRESPONSE"]._serialized_end = 1458
    _globals["_SEQUENCEUPDATEREQUEST"]._serialized_start = 1461
    _globals["_SEQUENCEUPDATEREQUEST"]._serialized_end = 1608
    _globals["_SEQUENCEUPDATERESPONSE"]._serialized_start = 1611
    _globals["_SEQUENCEUPDATERESPONSE"]._serialized_end = 1778
    _globals["_SEQUENCEDELETEREQUEST"]._serialized_start = 1780
    _globals["_SEQUENCEDELETEREQUEST"]._serialized_end = 1871
    _globals["_SEQUENCEDELETERESPONSE"]._serialized_start = 1873
    _globals["_SEQUENCEDELETERESPONSE"]._serialized_end = 1972
    _globals["_NEXTBYIDREQUEST"]._serialized_start = 1974
    _globals["_NEXTBYIDREQUEST"]._serialized_end = 2059
    _globals["_NEXTBYCODEREQUEST"]._serialized_start = 2061
    _globals["_NEXTBYCODEREQUEST"]._serialized_end = 2150
    _globals["_NEXTRESPONSE"]._serialized_start = 2152
    _globals["_NEXTRESPONSE"]._serialized_end = 2180
    _globals["_SEQUENCESERVICE"]._serialized_start = 2183
    _globals["_SEQUENCESERVICE"]._serialized_end = 3040
# @@protoc_insertion_point(module_scope)
