# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/calculate_delivery_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(v1/rules/calculate_delivery_method.proto\x12\x33pro.omni.oms.api.v1.rules.calculate_delivery_method\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/protobuf/struct.proto"\xa7\x01\n\x1b\x43\x61lculateDeliveryMethodData\x12-\n\x0c\x63\x61rt_details\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x31\n\x10shipping_details\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct"\xb8\x01\n\x1e\x43\x61lculateDeliveryMethodRequest\x12^\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32P.pro.omni.oms.api.v1.rules.calculate_delivery_method.CalculateDeliveryMethodData\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x98\x01\n\x1f\x43\x61lculateDeliveryMethodResponse\x12*\n\x06result\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xe9\x01\n\x1e\x43\x61lculateDeliveryMethodService\x12\xc6\x01\n\x17\x43\x61lculateDeliveryMethod\x12S.pro.omni.oms.api.v1.rules.calculate_delivery_method.CalculateDeliveryMethodRequest\x1aT.pro.omni.oms.api.v1.rules.calculate_delivery_method.CalculateDeliveryMethodResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.calculate_delivery_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CALCULATEDELIVERYMETHODDATA"]._serialized_start = 179
    _globals["_CALCULATEDELIVERYMETHODDATA"]._serialized_end = 346
    _globals["_CALCULATEDELIVERYMETHODREQUEST"]._serialized_start = 349
    _globals["_CALCULATEDELIVERYMETHODREQUEST"]._serialized_end = 533
    _globals["_CALCULATEDELIVERYMETHODRESPONSE"]._serialized_start = 536
    _globals["_CALCULATEDELIVERYMETHODRESPONSE"]._serialized_end = 688
    _globals["_CALCULATEDELIVERYMETHODSERVICE"]._serialized_start = 691
    _globals["_CALCULATEDELIVERYMETHODSERVICE"]._serialized_end = 924
# @@protoc_insertion_point(module_scope)
