# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/users/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13v1/users/user.proto\x12\x1epro.omni.oms.api.v1.users.user\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xec\x03\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sub\x18\x03 \x01(\t\x12\x0e\n\x06tenant\x18\x04 \x01(\t\x12\x10\n\x08username\x18\x05 \x01(\t\x12\r\n\x05\x65mail\x18\x06 \x01(\t\x12\x36\n\x08language\x18\x07 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12\x36\n\x08timezone\x18\x08 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12*\n\x06groups\x18\t \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x30\n\x0cis_superuser\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\'\n\x03mfa\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\r \x01(\t\x12?\n\x0cobject_audit\x18\x0e \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit\x12\x13\n\x0bpermissions\x18\x0f \x03(\t"\xdd\x01\n\x05Group\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12*\n\x06\x61\x63\x63\x65ss\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x06 \x01(\t\x12?\n\x0cobject_audit\x18\x07 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xec\x01\n\x06\x41\x63tion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0cmicroservice\x18\x05 \x01(\t\x12\r\n\x05model\x18\x06 \x01(\t\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x08 \x01(\t\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x8d\x02\n\x06\x41\x63\x63\x65ss\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0e\n\x06\x64omain\x18\x04 \x01(\t\x12\x11\n\taction_id\x18\x05 \x01(\t\x12\x36\n\x06\x61\x63tion\x18\x06 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x08 \x01(\t\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xa4\x03\n\x11UserCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x15\n\remail_confirm\x18\x04 \x01(\t\x12\x10\n\x08password\x18\x05 \x01(\t\x12\x18\n\x10password_confirm\x18\x06 \x01(\t\x12.\n\ngroups_ids\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x30\n\x0cis_superuser\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x08language\x18\t \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12\x36\n\x08timezone\x18\n \x01(\x0b\x32$.pro.omni.oms.api.common.base.Object\x12\x13\n\x0b\x65xternal_id\x18\x0b \x01(\t\x12\x36\n\x07\x63ontext\x18\x0c \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x12UserCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x32\n\x04user\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User"\xed\x02\n\x0fUserReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcd\x01\n\x10UserReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x33\n\x05users\x18\x03 \x03(\x0b\x32$.pro.omni.oms.api.v1.users.user.User"\x7f\n\x11UserUpdateRequest\x12\x32\n\x04user\x18\x01 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x12UserUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x32\n\x04user\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User"W\n\x11UserDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"_\n\x12UserDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8b\x01\n\x19UserChangePasswordRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x18\n\x10password_confirm\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"g\n\x1aUserChangePasswordResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x82\x01\n\x16UserChangeEmailRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x15\n\remail_confirm\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"d\n\x17UserChangeEmailResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x98\x01\n\x12GroupCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12.\n\naccess_ids\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x96\x01\n\x13GroupCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x34\n\x05group\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.v1.users.user.Group"\xee\x02\n\x10GroupReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd0\x01\n\x11GroupReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x35\n\x06groups\x18\x03 \x03(\x0b\x32%.pro.omni.oms.api.v1.users.user.Group"\x82\x01\n\x12GroupUpdateRequest\x12\x34\n\x05group\x18\x01 \x01(\x0b\x32%.pro.omni.oms.api.v1.users.user.Group\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x96\x01\n\x13GroupUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x34\n\x05group\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.v1.users.user.Group"X\n\x12GroupDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13GroupDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xb8\x01\n\x13\x41\x63tionCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0cmicroservice\x18\x04 \x01(\t\x12\r\n\x05model\x18\x05 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x99\x01\n\x14\x41\x63tionCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x36\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action"\xef\x02\n\x11\x41\x63tionReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd3\x01\n\x12\x41\x63tionReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x37\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action"\x85\x01\n\x13\x41\x63tionUpdateRequest\x12\x36\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x99\x01\n\x14\x41\x63tionUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x36\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Action"Y\n\x13\x41\x63tionDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"a\n\x14\x41\x63tionDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa1\x01\n\x13\x41\x63\x63\x65ssCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x11\n\taction_id\x18\x04 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x99\x01\n\x14\x41\x63\x63\x65ssCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Access"\xef\x02\n\x11\x41\x63\x63\x65ssReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd4\x01\n\x12\x41\x63\x63\x65ssReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x38\n\x08\x61\x63\x63\x65sses\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.users.user.Access"\x85\x01\n\x13\x41\x63\x63\x65ssUpdateRequest\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Access\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x99\x01\n\x14\x41\x63\x63\x65ssUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.users.user.Access"Y\n\x13\x41\x63\x63\x65ssDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"a\n\x14\x41\x63\x63\x65ssDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa3\x01\n\x12\x41\x63\x63\x65ssGroupRequest\x12.\n\naccess_ids\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x10\n\x08group_id\x18\x02 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13\x41\x63\x63\x65ssGroupResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8a\x01\n\x10GroupUserRequest\x12-\n\tgroup_ids\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"^\n\x11GroupUserResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"t\n\x14HasPermissionRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x12\n\npermission\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xae\x01\n\x15HasPermissionResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x16\n\x0ehas_permission\x18\x02 \x01(\x08\x12\x32\n\x04user\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User"j\n\x0cLoginRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"P\n\x14\x41uthenticationResult\x12\r\n\x05token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\x05"\xe3\x01\n\rLoginResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12S\n\x15\x61uthentication_result\x18\x02 \x01(\x0b\x32\x34.pro.omni.oms.api.v1.users.user.AuthenticationResult\x12\x32\n\x04user\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User"d\n\x13RefreshTokenRequest\x12\x36\n\x07\x63ontext\x18\x01 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context\x12\x15\n\rrefresh_token\x18\x02 \x01(\t"\xb6\x01\n\x14RefreshTokenResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12S\n\x15\x61uthentication_result\x18\x02 \x01(\x0b\x32\x34.pro.omni.oms.api.v1.users.user.AuthenticationResult2\x99\x18\n\x0cUsersService\x12u\n\nUserCreate\x12\x31.pro.omni.oms.api.v1.users.user.UserCreateRequest\x1a\x32.pro.omni.oms.api.v1.users.user.UserCreateResponse"\x00\x12o\n\x08UserRead\x12/.pro.omni.oms.api.v1.users.user.UserReadRequest\x1a\x30.pro.omni.oms.api.v1.users.user.UserReadResponse"\x00\x12u\n\nUserUpdate\x12\x31.pro.omni.oms.api.v1.users.user.UserUpdateRequest\x1a\x32.pro.omni.oms.api.v1.users.user.UserUpdateResponse"\x00\x12u\n\nUserDelete\x12\x31.pro.omni.oms.api.v1.users.user.UserDeleteRequest\x1a\x32.pro.omni.oms.api.v1.users.user.UserDeleteResponse"\x00\x12\x8d\x01\n\x12UserChangePassword\x12\x39.pro.omni.oms.api.v1.users.user.UserChangePasswordRequest\x1a:.pro.omni.oms.api.v1.users.user.UserChangePasswordResponse"\x00\x12\x84\x01\n\x0fUserChangeEmail\x12\x36.pro.omni.oms.api.v1.users.user.UserChangeEmailRequest\x1a\x37.pro.omni.oms.api.v1.users.user.UserChangeEmailResponse"\x00\x12x\n\x0bGroupCreate\x12\x32.pro.omni.oms.api.v1.users.user.GroupCreateRequest\x1a\x33.pro.omni.oms.api.v1.users.user.GroupCreateResponse"\x00\x12r\n\tGroupRead\x12\x30.pro.omni.oms.api.v1.users.user.GroupReadRequest\x1a\x31.pro.omni.oms.api.v1.users.user.GroupReadResponse"\x00\x12x\n\x0bGroupUpdate\x12\x32.pro.omni.oms.api.v1.users.user.GroupUpdateRequest\x1a\x33.pro.omni.oms.api.v1.users.user.GroupUpdateResponse"\x00\x12x\n\x0bGroupDelete\x12\x32.pro.omni.oms.api.v1.users.user.GroupDeleteRequest\x1a\x33.pro.omni.oms.api.v1.users.user.GroupDeleteResponse"\x00\x12{\n\x0c\x41\x63tionCreate\x12\x33.pro.omni.oms.api.v1.users.user.ActionCreateRequest\x1a\x34.pro.omni.oms.api.v1.users.user.ActionCreateResponse"\x00\x12u\n\nActionRead\x12\x31.pro.omni.oms.api.v1.users.user.ActionReadRequest\x1a\x32.pro.omni.oms.api.v1.users.user.ActionReadResponse"\x00\x12{\n\x0c\x41\x63tionUpdate\x12\x33.pro.omni.oms.api.v1.users.user.ActionUpdateRequest\x1a\x34.pro.omni.oms.api.v1.users.user.ActionUpdateResponse"\x00\x12{\n\x0c\x41\x63tionDelete\x12\x33.pro.omni.oms.api.v1.users.user.ActionDeleteRequest\x1a\x34.pro.omni.oms.api.v1.users.user.ActionDeleteResponse"\x00\x12{\n\x0c\x41\x63\x63\x65ssCreate\x12\x33.pro.omni.oms.api.v1.users.user.AccessCreateRequest\x1a\x34.pro.omni.oms.api.v1.users.user.AccessCreateResponse"\x00\x12u\n\nAccessRead\x12\x31.pro.omni.oms.api.v1.users.user.AccessReadRequest\x1a\x32.pro.omni.oms.api.v1.users.user.AccessReadResponse"\x00\x12{\n\x0c\x41\x63\x63\x65ssUpdate\x12\x33.pro.omni.oms.api.v1.users.user.AccessUpdateRequest\x1a\x34.pro.omni.oms.api.v1.users.user.AccessUpdateResponse"\x00\x12{\n\x0c\x41\x63\x63\x65ssDelete\x12\x33.pro.omni.oms.api.v1.users.user.AccessDeleteRequest\x1a\x34.pro.omni.oms.api.v1.users.user.AccessDeleteResponse"\x00\x12~\n\rHasPermission\x12\x34.pro.omni.oms.api.v1.users.user.HasPermissionRequest\x1a\x35.pro.omni.oms.api.v1.users.user.HasPermissionResponse"\x00\x12\x66\n\x05Login\x12,.pro.omni.oms.api.v1.users.user.LoginRequest\x1a-.pro.omni.oms.api.v1.users.user.LoginResponse"\x00\x12{\n\x0cRefreshToken\x12\x33.pro.omni.oms.api.v1.users.user.RefreshTokenRequest\x1a\x34.pro.omni.oms.api.v1.users.user.RefreshTokenResponse"\x00\x12}\n\x10\x41\x64\x64\x41\x63\x63\x65ssToGroup\x12\x32.pro.omni.oms.api.v1.users.user.AccessGroupRequest\x1a\x33.pro.omni.oms.api.v1.users.user.AccessGroupResponse"\x00\x12\x82\x01\n\x15RemoveAccessFromGroup\x12\x32.pro.omni.oms.api.v1.users.user.AccessGroupRequest\x1a\x33.pro.omni.oms.api.v1.users.user.AccessGroupResponse"\x00\x12w\n\x0e\x41\x64\x64GroupToUser\x12\x30.pro.omni.oms.api.v1.users.user.GroupUserRequest\x1a\x31.pro.omni.oms.api.v1.users.user.GroupUserResponse"\x00\x12|\n\x13RemoveGroupFromUser\x12\x30.pro.omni.oms.api.v1.users.user.GroupUserRequest\x1a\x31.pro.omni.oms.api.v1.users.user.GroupUserResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.users.user_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_USER"]._serialized_start = 137
    _globals["_USER"]._serialized_end = 629
    _globals["_GROUP"]._serialized_start = 632
    _globals["_GROUP"]._serialized_end = 853
    _globals["_ACTION"]._serialized_start = 856
    _globals["_ACTION"]._serialized_end = 1092
    _globals["_ACCESS"]._serialized_start = 1095
    _globals["_ACCESS"]._serialized_end = 1364
    _globals["_USERCREATEREQUEST"]._serialized_start = 1367
    _globals["_USERCREATEREQUEST"]._serialized_end = 1787
    _globals["_USERCREATERESPONSE"]._serialized_start = 1790
    _globals["_USERCREATERESPONSE"]._serialized_end = 1937
    _globals["_USERREADREQUEST"]._serialized_start = 1940
    _globals["_USERREADREQUEST"]._serialized_end = 2305
    _globals["_USERREADRESPONSE"]._serialized_start = 2308
    _globals["_USERREADRESPONSE"]._serialized_end = 2513
    _globals["_USERUPDATEREQUEST"]._serialized_start = 2515
    _globals["_USERUPDATEREQUEST"]._serialized_end = 2642
    _globals["_USERUPDATERESPONSE"]._serialized_start = 2645
    _globals["_USERUPDATERESPONSE"]._serialized_end = 2792
    _globals["_USERDELETEREQUEST"]._serialized_start = 2794
    _globals["_USERDELETEREQUEST"]._serialized_end = 2881
    _globals["_USERDELETERESPONSE"]._serialized_start = 2883
    _globals["_USERDELETERESPONSE"]._serialized_end = 2978
    _globals["_USERCHANGEPASSWORDREQUEST"]._serialized_start = 2981
    _globals["_USERCHANGEPASSWORDREQUEST"]._serialized_end = 3120
    _globals["_USERCHANGEPASSWORDRESPONSE"]._serialized_start = 3122
    _globals["_USERCHANGEPASSWORDRESPONSE"]._serialized_end = 3225
    _globals["_USERCHANGEEMAILREQUEST"]._serialized_start = 3228
    _globals["_USERCHANGEEMAILREQUEST"]._serialized_end = 3358
    _globals["_USERCHANGEEMAILRESPONSE"]._serialized_start = 3360
    _globals["_USERCHANGEEMAILRESPONSE"]._serialized_end = 3460
    _globals["_GROUPCREATEREQUEST"]._serialized_start = 3463
    _globals["_GROUPCREATEREQUEST"]._serialized_end = 3615
    _globals["_GROUPCREATERESPONSE"]._serialized_start = 3618
    _globals["_GROUPCREATERESPONSE"]._serialized_end = 3768
    _globals["_GROUPREADREQUEST"]._serialized_start = 3771
    _globals["_GROUPREADREQUEST"]._serialized_end = 4137
    _globals["_GROUPREADRESPONSE"]._serialized_start = 4140
    _globals["_GROUPREADRESPONSE"]._serialized_end = 4348
    _globals["_GROUPUPDATEREQUEST"]._serialized_start = 4351
    _globals["_GROUPUPDATEREQUEST"]._serialized_end = 4481
    _globals["_GROUPUPDATERESPONSE"]._serialized_start = 4484
    _globals["_GROUPUPDATERESPONSE"]._serialized_end = 4634
    _globals["_GROUPDELETEREQUEST"]._serialized_start = 4636
    _globals["_GROUPDELETEREQUEST"]._serialized_end = 4724
    _globals["_GROUPDELETERESPONSE"]._serialized_start = 4726
    _globals["_GROUPDELETERESPONSE"]._serialized_end = 4822
    _globals["_ACTIONCREATEREQUEST"]._serialized_start = 4825
    _globals["_ACTIONCREATEREQUEST"]._serialized_end = 5009
    _globals["_ACTIONCREATERESPONSE"]._serialized_start = 5012
    _globals["_ACTIONCREATERESPONSE"]._serialized_end = 5165
    _globals["_ACTIONREADREQUEST"]._serialized_start = 5168
    _globals["_ACTIONREADREQUEST"]._serialized_end = 5535
    _globals["_ACTIONREADRESPONSE"]._serialized_start = 5538
    _globals["_ACTIONREADRESPONSE"]._serialized_end = 5749
    _globals["_ACTIONUPDATEREQUEST"]._serialized_start = 5752
    _globals["_ACTIONUPDATEREQUEST"]._serialized_end = 5885
    _globals["_ACTIONUPDATERESPONSE"]._serialized_start = 5888
    _globals["_ACTIONUPDATERESPONSE"]._serialized_end = 6041
    _globals["_ACTIONDELETEREQUEST"]._serialized_start = 6043
    _globals["_ACTIONDELETEREQUEST"]._serialized_end = 6132
    _globals["_ACTIONDELETERESPONSE"]._serialized_start = 6134
    _globals["_ACTIONDELETERESPONSE"]._serialized_end = 6231
    _globals["_ACCESSCREATEREQUEST"]._serialized_start = 6234
    _globals["_ACCESSCREATEREQUEST"]._serialized_end = 6395
    _globals["_ACCESSCREATERESPONSE"]._serialized_start = 6398
    _globals["_ACCESSCREATERESPONSE"]._serialized_end = 6551
    _globals["_ACCESSREADREQUEST"]._serialized_start = 6554
    _globals["_ACCESSREADREQUEST"]._serialized_end = 6921
    _globals["_ACCESSREADRESPONSE"]._serialized_start = 6924
    _globals["_ACCESSREADRESPONSE"]._serialized_end = 7136
    _globals["_ACCESSUPDATEREQUEST"]._serialized_start = 7139
    _globals["_ACCESSUPDATEREQUEST"]._serialized_end = 7272
    _globals["_ACCESSUPDATERESPONSE"]._serialized_start = 7275
    _globals["_ACCESSUPDATERESPONSE"]._serialized_end = 7428
    _globals["_ACCESSDELETEREQUEST"]._serialized_start = 7430
    _globals["_ACCESSDELETEREQUEST"]._serialized_end = 7519
    _globals["_ACCESSDELETERESPONSE"]._serialized_start = 7521
    _globals["_ACCESSDELETERESPONSE"]._serialized_end = 7618
    _globals["_ACCESSGROUPREQUEST"]._serialized_start = 7621
    _globals["_ACCESSGROUPREQUEST"]._serialized_end = 7784
    _globals["_ACCESSGROUPRESPONSE"]._serialized_start = 7786
    _globals["_ACCESSGROUPRESPONSE"]._serialized_end = 7882
    _globals["_GROUPUSERREQUEST"]._serialized_start = 7885
    _globals["_GROUPUSERREQUEST"]._serialized_end = 8023
    _globals["_GROUPUSERRESPONSE"]._serialized_start = 8025
    _globals["_GROUPUSERRESPONSE"]._serialized_end = 8119
    _globals["_HASPERMISSIONREQUEST"]._serialized_start = 8121
    _globals["_HASPERMISSIONREQUEST"]._serialized_end = 8237
    _globals["_HASPERMISSIONRESPONSE"]._serialized_start = 8240
    _globals["_HASPERMISSIONRESPONSE"]._serialized_end = 8414
    _globals["_LOGINREQUEST"]._serialized_start = 8416
    _globals["_LOGINREQUEST"]._serialized_end = 8522
    _globals["_AUTHENTICATIONRESULT"]._serialized_start = 8524
    _globals["_AUTHENTICATIONRESULT"]._serialized_end = 8604
    _globals["_LOGINRESPONSE"]._serialized_start = 8607
    _globals["_LOGINRESPONSE"]._serialized_end = 8834
    _globals["_REFRESHTOKENREQUEST"]._serialized_start = 8836
    _globals["_REFRESHTOKENREQUEST"]._serialized_end = 8936
    _globals["_REFRESHTOKENRESPONSE"]._serialized_start = 8939
    _globals["_REFRESHTOKENRESPONSE"]._serialized_end = 9121
    _globals["_USERSSERVICE"]._serialized_start = 9124
    _globals["_USERSSERVICE"]._serialized_end = 12221
# @@protoc_insertion_point(module_scope)
